# -*- coding: utf-8 -*-

from .stream import Stream, DictStream
ItemStream = Stream
MapStream = DictStream
